@@ -157,6 +157,9 @@
 /* Qt's native path separator is '/', regardless of the current OS. */
 #define OSPATHCHAR '/' /* Normal path separator character. */
 
+/* ASCII string giving the local newline sequence to write on output. */
+#define OS_NEWLINE_SEQ "\n"
+
 typedef FILE osfildef; /* File handle structure for osfxxx functions. */
 
 /* Open text file for reading.
