@@ -394,7 +394,7 @@ int CVmObjLookupTable::get_prop(VMG_ vm_prop_id_t prop, vm_val_t *retval,
                                 vm_obj_id_t self, vm_obj_id_t *source_obj,
                                 uint *argc)
 {
-    ushort func_idx;
+    uint func_idx;
 
     /* translate the property into a function vector index */
     func_idx = G_meta_table
@@ -779,7 +779,7 @@ void CVmObjLookupTable::add_entry(VMG_
     G_stk->push(val);
     
     /* calculate the hash value for the key */
-    hashval = calc_hash(vmg_ key);
+    hashval = calc_key_hash(vmg_ key);
 
     /* allocate an entry */
     entry = alloc_new_entry(vmg0_);
@@ -902,7 +902,7 @@ vm_lookup_val *CVmObjLookupTable::find_entry(VMG_ const vm_val_t *key,
     vm_lookup_val *prv_entry;
 
     /* compute the hash value (and return it to the caller if desired) */
-    hashval = calc_hash(vmg_ key);
+    hashval = calc_key_hash(vmg_ key);
     if (hashval_p != 0)
         *hashval_p = hashval;
 
@@ -925,9 +925,9 @@ vm_lookup_val *CVmObjLookupTable::find_entry(VMG_ const vm_val_t *key,
 
 
 /*
- *   Calculate a hash value 
+ *   Calculate a hash value for a key
  */
-uint CVmObjLookupTable::calc_hash(VMG_ const vm_val_t *key)
+uint CVmObjLookupTable::calc_key_hash(VMG_ const vm_val_t *key)
 {
     uint hash;
     
